==> huaweicloudsdkrms-3.0.46-py2.py3-none-any.whl: huaweicloudsdkrms/v1/model/update_policy_assignment_request.py <==
# coding: utf-8

import pprint
import re

import six





class UpdatePolicyAssignmentRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'policy_assignment_id': 'str',
        'body': 'PolicyAssignmentRequestBody'
    }

    attribute_map = {
        'policy_assignment_id': 'policy_assignment_id',
        'body': 'body'
    }

    def __init__(self, policy_assignment_id=None, body=None):
        """UpdatePolicyAssignmentRequest - a model defined in huaweicloud sdk"""
        
        

        self._policy_assignment_id = None
        self._body = None
        self.discriminator = None

        self.policy_assignment_id = policy_assignment_id
        if body is not None:
            self.body = body

    @property
    def policy_assignment_id(self):
        """Gets the policy_assignment_id of this UpdatePolicyAssignmentRequest.

        规则ID

        :return: The policy_assignment_id of this UpdatePolicyAssignmentRequest.
        :rtype: str
        """
        return self._policy_assignment_id

    @policy_assignment_id.setter
    def policy_assignment_id(self, policy_assignment_id):
        """Sets the policy_assignment_id of this UpdatePolicyAssignmentRequest.

        规则ID

        :param policy_assignment_id: The policy_assignment_id of this UpdatePolicyAssignmentRequest.
        :type: str
        """
        self._policy_assignment_id = policy_assignment_id

    @property
    def body(self):
        """Gets the body of this UpdatePolicyAssignmentRequest.


        :return: The body of this UpdatePolicyAssignmentRequest.
        :rtype: PolicyAssignmentRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdatePolicyAssignmentRequest.


        :param body: The body of this UpdatePolicyAssignmentRequest.
        :type: PolicyAssignmentRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePolicyAssignmentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrms-3.0.51-py2.py3-none-any.whl: huaweicloudsdkrms/v1/model/update_policy_assignment_request.py <==
# coding: utf-8

import re
import six





class UpdatePolicyAssignmentRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'policy_assignment_id': 'str',
        'body': 'PolicyAssignmentRequestBody'
    }

    attribute_map = {
        'policy_assignment_id': 'policy_assignment_id',
        'body': 'body'
    }

    def __init__(self, policy_assignment_id=None, body=None):
        """UpdatePolicyAssignmentRequest - a model defined in huaweicloud sdk"""
        
        

        self._policy_assignment_id = None
        self._body = None
        self.discriminator = None

        self.policy_assignment_id = policy_assignment_id
        if body is not None:
            self.body = body

    @property
    def policy_assignment_id(self):
        """Gets the policy_assignment_id of this UpdatePolicyAssignmentRequest.

        规则ID

        :return: The policy_assignment_id of this UpdatePolicyAssignmentRequest.
        :rtype: str
        """
        return self._policy_assignment_id

    @policy_assignment_id.setter
    def policy_assignment_id(self, policy_assignment_id):
        """Sets the policy_assignment_id of this UpdatePolicyAssignmentRequest.

        规则ID

        :param policy_assignment_id: The policy_assignment_id of this UpdatePolicyAssignmentRequest.
        :type: str
        """
        self._policy_assignment_id = policy_assignment_id

    @property
    def body(self):
        """Gets the body of this UpdatePolicyAssignmentRequest.


        :return: The body of this UpdatePolicyAssignmentRequest.
        :rtype: PolicyAssignmentRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdatePolicyAssignmentRequest.


        :param body: The body of this UpdatePolicyAssignmentRequest.
        :type: PolicyAssignmentRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatePolicyAssignmentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
